import { 
  select, 
  csv, 
  scaleLinear, 
  scalePoint, 
  max,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const xValue = d => d.population;
  const yValue = d => d.country; 
  
  const margin = {top: 50, right: 40, bottom: 75, left: 180};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scalePoint()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(.7);
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxisTickFormat = number => 
  	format('.2s')(number)
  		.replace('G', 'B');
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth);
  
  g.append('g')
    .call(yAxis)
  	.select('.domain')
    	.remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  	xAxisG.select('.domain').remove();
  
	g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', 18);
  
  g.append('text')
  	.text('Top 10 most populous countries')
  	.attr('y', -10)
  	.attr('class', 'plot-title');
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.text('Population')
  	.attr('fill', 'black')
  	.attr('x', innerWidth / 2)
  	.attr('y', 60);
  
}

csv('data.csv').then(data => {
	data.forEach(d => {
  	d.population = +d.population * 1000;
  });
  render(data);
});



























